/// <reference types="node" />
import { Context, FileProcessor, ModuleDefinition } from "@code-engine/types";
import { EventEmitter } from "events";
/**
 * Runs CodeEngine plugins on worker threads.
 */
export declare class WorkerPool extends EventEmitter {
    constructor(concurrency: number, context: Context);
    /**
     * Indicates the number of worker threads in the pool.
     */
    readonly size: number;
    /**
     * Indicates whether the `dispose()` method has been called.
     * Once disposed, the `WorkerPool` instance is no longer usable.
     */
    readonly isDisposed: boolean;
    /**
     * Loads the specified JavaScript module in all worker threads and returns a `FileProcessor` wrapper
     * that executes the module in one of the threads.
     */
    loadFileProcessor(module: string | ModuleDefinition): Promise<FileProcessor>;
    /**
     * Terminates all worker threads.
     */
    dispose(): Promise<void>;
}
